# Inventory
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/inventory#overview)
  * [Searching and Filtering for Fact Sheets](https://help.sap.com/docs/leanix/ea/inventory#searching-and-filtering-for-fact-sheets)
  * [Creating a New Fact Sheet](https://help.sap.com/docs/leanix/ea/inventory#creating-a-new-fact-sheet)
  * [Importing and Exporting Fact Sheets](https://help.sap.com/docs/leanix/ea/inventory#importing-and-exporting-fact-sheets)
  * [List View and Table View](https://help.sap.com/docs/leanix/ea/inventory#list-view-and-table-view)
  * [Data Quality Insight Cards](https://help.sap.com/docs/leanix/ea/inventory#data-quality-insight-cards)
  * [Detailed Guides](https://help.sap.com/docs/leanix/ea/inventory#detailed-guides)


The inventory is your centralized repository for managing and documenting enterprise architecture objects. You create, edit, and organize fact sheets to maintain an accurate depiction of your IT landscape. It is the go-to place for anyone seeking information from the fact sheets.
